## v0.0.4
* Fix Nexmo client initialization.

## v0.0.3
* Correct the depencency specifiers in v0.0.2.

## v0.0.2
* Relax dependency versions to make the app easier to work with.
* Fix compatibility with rc versions of Marshmallow.
